@@ -12,9 +12,11 @@ def main(f=sys.stdout, **kwargs):
     def out(s, **kwargs):
         print(s, file=f, **kwargs)
 
-    def _rst_header(char, text, newline=True):
+    def _rst_header(char, text, newline=True, leading=False):
         if newline:
-            out('\n', end='')
+            out("\n", end="")
+        if leading:
+            out(char * len(text))
         out(text)
         out(char * len(text))
 
@@ -22,25 +24,25 @@ def main(f=sys.stdout, **kwargs):
     if __doc__ is not None:
         out(__doc__.strip())
 
-    _rst_header('=', 'Reporters', newline=False)
+    _rst_header("=", "Reporters", newline=False)
 
     for reporter in objects.REPORTERS.values():
         if reporter.__doc__ is not None:
             try:
-                summary, explanation = reporter.__doc__.split('\n', 1)
+                summary, explanation = reporter.__doc__.split("\n", 1)
             except ValueError:
                 summary = reporter.__doc__
                 explanation = None
         else:
             summary = None
 
-        _rst_header('-', reporter.__name__)
+        _rst_header("-", reporter.__name__, leading=True)
         if summary:
-            out('\n' + dedent(summary).strip())
+            out("\n" + dedent(summary).strip())
             if explanation:
-                explanation = '\n'.join(dedent(explanation).strip().split('\n'))
-                out('\n' + explanation)
+                explanation = "\n".join(dedent(explanation).strip().split("\n"))
+                out("\n" + explanation)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
